package com.cm.common.service.templateconfig.impl;

import com.cm.common.base.AbstractService;
import com.cm.common.dao.templateconfig.ITemplateConfigDao;
import com.cm.common.exception.RemoveException;
import com.cm.common.exception.SaveException;
import com.cm.common.exception.SearchException;
import com.cm.common.exception.UpdateException;
import com.cm.common.pojo.ListPage;
import com.cm.common.pojo.dtos.templateconfig.TemplateConfigDTO;
import com.cm.common.pojo.vos.templateconfig.TemplateConfigVO;
import com.cm.common.result.SuccessResult;
import com.cm.common.result.SuccessResultList;
import com.cm.common.service.templaterecord.ITemplateRecordService;
import com.cm.common.service.templateconfig.ITemplateConfigService;
import com.cm.common.util.TemplateBuilderUtil;
import com.cm.common.utils.HashMapUtil;
import com.cm.common.utils.UUIDUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @ClassName: TemplateConfigServiceImpl
 * @Description: 新闻模板表
 * @Author: WenG
 * @Date: 2020-05-07 16:44
 * @Version: 1.0
 **/
@Service
public class TemplateConfigServiceImpl extends AbstractService implements ITemplateConfigService {

    @Autowired
    private ITemplateConfigDao templateConfigDao;
    @Autowired
    private ITemplateRecordService iTemplateConfigRecordService;

    @Override
    public SuccessResult saveTemplateConfig(TemplateConfigVO templateConfigVO) throws Exception {
        saveTemplateConfigInfo(null, templateConfigVO);
        return new SuccessResult();
    }

    @Override
    public SuccessResult saveTemplateConfigByToken(String token, TemplateConfigVO templateConfigVO) throws Exception {
        saveTemplateConfigInfo(token, templateConfigVO);
        return new SuccessResult();
    }

    /**
     * 新增新闻模板表
     *
     * @param token
     * @param templateConfigVO
     * @throws Exception
     */
    private void saveTemplateConfigInfo(String token, TemplateConfigVO templateConfigVO) throws Exception {
        Map<String, Object> params = HashMapUtil.beanToMap(templateConfigVO);
        String templateConfigId = UUIDUtil.getUUID();
        params.put("templateConfigId", templateConfigId);
        if (token != null) {
            setSaveInfo(token, params);
        } else {
            setSaveInfo(params);
        }
        /**
         * 查询编码是否已经存在
         */
        TemplateConfigDTO DTO = templateConfigDao.getTemplateConfigByCode(params);
        if(DTO != null) {
            throw new SaveException("该编码已经存在");
        }
        templateConfigDao.saveTemplateConfig(params);
        /**
         * 更新保存操作 2020年5月8日16:02:39 崔宝铖
         */
        Map<String, Object> query = super.getHashMap(1);
        query.put("templateConfigId", templateConfigId);
        TemplateConfigDTO templateDTO = templateConfigDao.getTemplateConfig(query);
        TemplateBuilderUtil.getInstance().pushTemplate(templateDTO.getTemplateCode(), templateDTO);
    }

    @Override
    public SuccessResult removeTemplateConfig(String ids) throws RemoveException {
        removeTemplateConfigInfo(null, ids);
        return new SuccessResult();
    }

    @Override
    public SuccessResult removeTemplateConfigByToken(String token, String ids) throws RemoveException {
        removeTemplateConfigInfo(token, ids);
        return new SuccessResult();
    }

    /**
     * 删除新闻模板表
     *
     * @param token
     * @param ids
     */
    private void removeTemplateConfigInfo(String token, String ids) {
        Map<String, Object> params = getHashMap(3);
        List<String> list = Arrays.asList(ids.split("_"));
        /**
         * 更新删除操作 2020年5月8日16:02:39 崔宝铖
         */
        Map<String, Object> query = super.getHashMap(1);
        for (String templateConfigId:  list) {
            query.put("templateConfigId", templateConfigId);
            TemplateConfigDTO templateDTO = templateConfigDao.getTemplateConfig(query);
            TemplateBuilderUtil.getInstance().removeTemplate(templateDTO.getTemplateCode());
        }
        /**
         * 更新删除操作
         */
        params.put("templateConfigIds", list);
        if (token != null) {
            setUpdateInfo(token, params);
        } else {
            setUpdateInfo(params);
        }
        templateConfigDao.removeTemplateConfig(params);
    }

    @Override
    public SuccessResult updateTemplateConfig(String templateConfigId, TemplateConfigVO templateConfigVO) throws Exception {
        updateTemplateConfigInfo(null, templateConfigId, templateConfigVO);
        return new SuccessResult();
    }

    @Override
    public SuccessResult updateTemplateConfigByToken(String token, String templateConfigId, TemplateConfigVO templateConfigVO) throws Exception {
        updateTemplateConfigInfo(token, templateConfigId, templateConfigVO);
        return new SuccessResult();
    }

    /**
     * 修改新闻模板表
     *
     * @param token
     * @param templateConfigId
     * @param templateConfigVO
     */
    private void updateTemplateConfigInfo(String token, String templateConfigId, TemplateConfigVO templateConfigVO) throws Exception {
        Map<String, Object> params = HashMapUtil.beanToMap(templateConfigVO);
        params.put("templateConfigId", templateConfigId);
        if (token != null) {
            setUpdateInfo(token, params);
        } else {
            setUpdateInfo(params);
        }
        templateConfigDao.updateTemplateConfig(params);
        /**
         * 更新修改操作 2020年5月8日16:02:39 崔宝铖
         */
        Map<String, Object> query = super.getHashMap(1);
        query.put("templateConfigId", templateConfigId);
        TemplateConfigDTO templateDTO = templateConfigDao.getTemplateConfig(query);
        TemplateBuilderUtil.getInstance().pushTemplate(templateDTO.getTemplateCode(), templateDTO);
        /**
         * 更新修改操作
         */
    }

    @Override
    public TemplateConfigDTO getTemplateConfigById(String templateConfigId) throws SearchException {
        Map<String, Object> params = super.getHashMap(1);
        params.put("templateConfigId", templateConfigId);
        return templateConfigDao.getTemplateConfig(params);
    }

    @Override
    public List<TemplateConfigDTO> listTemplateConfig(Map<String, Object> params) throws SearchException {
        return templateConfigDao.listTemplateConfig(params);
    }

    @Override
    public SuccessResultList<List<TemplateConfigDTO>> listPageTemplateConfig(ListPage page) throws SearchException {
        PageHelper.startPage(page.getPage(), page.getRows());
        List<TemplateConfigDTO> templateConfigDTOs = templateConfigDao.listTemplateConfig(page.getParams());
        PageInfo<TemplateConfigDTO> pageInfo = new PageInfo<>(templateConfigDTOs);
        return new SuccessResultList<>(templateConfigDTOs, pageInfo.getPageNum(), pageInfo.getTotal());
    }

    @Override
    public SuccessResult updateTemplateConfigContent(String templateConfigId, String templateContent) throws Exception {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("templateConfigId", templateConfigId);
        params.put("templateContent", templateContent);
        if(StringUtils.isEmpty(templateContent)) {
            throw new UpdateException("模板内容不能为空!");
        }
        setUpdateInfo(params);
        templateConfigDao.updateTemplateConfigContent(params);
        /**
         * 更新修改操作 2020年5月8日16:02:39 崔宝铖
         */
        Map<String, Object> query = super.getHashMap(1);
        query.put("templateConfigId", templateConfigId);
        TemplateConfigDTO templateDTO = templateConfigDao.getTemplateConfig(query);
        TemplateBuilderUtil.getInstance().pushTemplate(templateDTO.getTemplateCode(), templateDTO);
        /**
         * 更新修改操作
         */
        return new SuccessResult();
    }

}
